/* Keyboard controller: scancode table for Genius KB-10X V2 (model K632).

In fact, the matrix is identical to keytab-gb.h, but the rows
and columns are renumbered, and the Sleep key is added.

Copyright (C) 2016 Ineiev <ineiev@gnu.org>, super V 93

This file is a part of miguel the keyboard controller.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <https://www.gnu.org/licenses/>.*/

/* The lower half of the table is hardcoded to save PROGMEM space
   (about 100 bytes).  */
enum keytab_constants { KEYTAB_SIZE = 1 << 7 };
PROGMEM static const unsigned char keytab[KEYTAB_SIZE] =
{
  0x03, 0x16, 0x3A, 0x1F, 0x1B, 0x1A, 0x03, 0x39,
  0x03, 0x0E, 0x2E, 0x25, 0x36, 0x0C, 0x3F, 0x30,
  0x03, 0x07, 0x3B, 0x20, 0x06, 0x08, 0x3D, 0x3C,
  0x03, 0x04, 0x35, 0x1E, 0x1D, 0x14, 0x29, 0x2B,
  0x65, 0x0F, 0x41, 0x26, 0x37, 0x12, 0x03, 0x40,
  0x11, 0x0D, 0x23, 0x24, 0x10, 0x18, 0x0B, 0x1C,
  0x05, 0x09, 0x22, 0x21, 0x19, 0x15, 0x0A, 0x17,
  0x38, 0x33, 0x2D, 0x27, 0x03, 0x13, 0x34, 0x2F,
  0x45, 0x31, 0x42, 0x43, 0x28, 0x03, 0x44, 0x2A,
  0x56, 0x5B, 0x4B, 0x4E, 0x55, 0x61, 0x63, 0x5E,
  0x51, 0x59, 0x4C, 0x03, 0x53, 0x5F, 0x2C, 0x5C,
  /* 0x00 in the next row is for the Sleep key. */
  0x4F, 0x5A, 0x49, 0x00, 0x54, 0x60, 0x62, 0x5D,
  0x03, 0x03, 0xE0, 0x3E, 0xE4, 0x48, 0x03, 0x03,
  0xE6, 0x03, 0x03, 0x46, 0x03, 0x47, 0xE2, 0x03,
  0x50, 0x58, 0x4A, 0x4D, 0x03, 0x57, 0x52, 0x03,
  0x03, 0xE5, 0x03, 0x03, 0x03, 0x03, 0x03, 0xE1,
};
static unsigned char
scan_to_code (unsigned char x)
{
  if (x < KEYTAB_SIZE)
    memcpy_P (&x, keytab + x, 1);
  else if (x == 0xC1)
    x = 0xE7;
  else if (x == 0x87)
    x = 0xE3;
  else
    x = 0x03;
  return x;
}
#define UNUSED_COLUMNS (10)
PROGMEM const unsigned char unused_columns[UNUSED_COLUMNS] =
{
  17 - PROBE_E1 + PROBE_E2,
  18 - PROBE_E1 + PROBE_E2,
  20 - PROBE_E1 + PROBE_E2,
  21 - PROBE_E1 + PROBE_E2,
  22 - PROBE_E1 + PROBE_E2,
  25 - PROBE_E1 + PROBE_E2,
  26 - PROBE_E1 + PROBE_E2,
  28 - PROBE_E1 + PROBE_E2,
  29 - PROBE_E1 + PROBE_E2,
  30 - PROBE_E1 + PROBE_E2
};
